@@ -6,7 +6,7 @@ use base 'HTML::Tested::Test::Value';
 
 sub _is_anyone_sealed {
 	my ($class, $e_root, $js) = @_;
-	return 1 if $e_root->{"__HT_SEALED__$js"};
+	return 1 if $class->SUPER::is_marked_as_sealed($e_root, $js);
 	my $a = $e_root->{$js};
 	return undef unless ref($a);
 	for my $r (@$a) {
@@ -17,25 +17,25 @@ sub _is_anyone_sealed {
 	return undef;
 }
 
-sub _handle_sealed {
-	my ($class, $e_root, $name, $e_val, $r_val, $err) = @_;
+sub is_marked_as_sealed {
+	my ($class, $e_root, $name) = @_;
 	my $ser_widget = $e_root->ht_find_widget($name);
 	for my $j (@{ $ser_widget->{_jses} }) {
 		next unless $class->_is_anyone_sealed($e_root, $j);
-		$e_root->{"__HT_SEALED__$name"} = 1;
-		last;
+		return 1;
 	}
-	return shift()->SUPER::_handle_sealed(@_);
+	return undef;
 }
 
 package HTML::Tested::JavaScript::Test;
-use HTML::Tested::Test;
+use HTML::Tested::Test qw(Register_Widget_Tester);
 use HTML::Tested::JavaScript::Serializer;
+use HTML::Tested::JavaScript::RichEdit;
+use HTML::Tested::JavaScript::Test::RichEdit;
 
-{
-	no strict 'refs';
-	*{ "HTML::Tested::JavaScript::Serializer::__ht_tester" } = sub {
-		return 'HTML::Tested::JavaScript::Test::Serializer'; };
-};
+Register_Widget_Tester("HTML::Tested::JavaScript::Serializer"
+		, 'HTML::Tested::JavaScript::Test::Serializer');
+Register_Widget_Tester("HTML::Tested::JavaScript::RichEdit"
+		, 'HTML::Tested::JavaScript::Test::RichEdit');
 
 1;
